@@ -24,7 +24,6 @@
 #include <string.h>
 #include <stdint.h>
 #include <stdlib.h>
-#include <assert.h>
 
 /* Macros to avoid using strcmp directly.  */
 
@@ -83,7 +82,7 @@ uint64_t pk_upow (uint64_t base, uint32_t exp);
 int pk_format_binary (char* out, size_t outlen, uint64_t val, int size,
                       int sign_p, int use_suffix_p);
 
-/* Concatenate string arguments into an malloc'ed string. */
+/* Concatenate string arguments into an malloc'ed string.  */
 char *pk_str_concat (const char *s0, ...) __attribute__ ((sentinel));
 
 /* Replace all occurrences of SEARCH within IN by REPLACE. */
@@ -92,22 +91,6 @@ char *pk_str_replace (const char *in, const char *search, const char *replace);
 /* Left and right trim the given string from whitespaces.  */
 void pk_str_trim (char **str);
 
-/* Convert floating-point number in input string STR and save the
-   result in *FLT.  On conversion error, the function will return a
-   non-zero value.
-
-   Note that the whole STR should be a valid floating-point number and
-   leading whitespace(s) will be ignored.  */
-int pvm_stof (const char *str, float *flt) __attribute__ ((nonnull));
-
-/* Convert floating-point number in input string STR and save the
-   result in *DBL.  On conversion error, the function will return a
-   non-zero value.
-
-   Note that the whole STR should be a valid floating-point number and
-   leading whitespace(s) will be ignored.  */
-int pvm_stod (const char *str, double *dbl) __attribute__ ((nonnull));
-
 /* This function is called when the program reaches a supposedly
    unreachable point; print an error message and abort the execution.
 
