@@ -1,24 +1,24 @@
 /* JitterLisp: heap allocation.
 
-   Copyright (C) 2017, 2018 Luca Saiu
-   Updated in 2020 by Luca Saiu
+   Copyright (C) 2017, 2018, 2021 Luca Saiu
+   Updated in 2020 and 2022 by Luca Saiu
    Written by Luca Saiu
 
    This file is part of the JitterLisp language implementation, distributed as
-   an example along with Jitter under the same license.
+   an example along with GNU Jitter under the same license.
 
-   Jitter is free software: you can redistribute it and/or modify
+   GNU Jitter is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
 
-   Jitter is distributed in the hope that it will be useful,
+   GNU Jitter is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with Jitter.  If not, see <http://www.gnu.org/licenses/>. */
+   along with GNU Jitter.  If not, see <https://www.gnu.org/licenses/>. */
 
 
 /* Include the Gnulib header. */
@@ -223,11 +223,11 @@ jitterlisp_pop_all_gc_roots (void)
  * ************************************************************************** */
 
 /* If littering then we simply use global variables for limits, and large
-   infrequently allocated blocks for the heap.  This is currently suboptimal, as
-   these should stay in registers; but I can live with this until a proper VM
-   for JitterLisp exists. */
+   infrequently allocated blocks for the heap.  This is obviously suboptimal,
+   but this entire littering allocator is a toy; the real Jitter garbage
+   collector will be less naïf. */
 #ifdef JITTERLISP_LITTER
-#define JITTERLISP_LITTER_BLOCK_BYTE_NO (1 * 1024L * 1024L)
+#define JITTERLISP_LITTER_BLOCK_BYTE_NO (32 * 1024L * 1024L)
 
 /* The lowest heap address. */
 static char *litter_heap_beginning;
@@ -275,6 +275,13 @@ jitterlisp_add_litter_block (size_t block_size_in_bytes)
     = jitter_xmalloc (block_size_in_bytes);
   litter_allocator_limit = (litter_allocator_pointer + block_size_in_bytes);
 
+  /* For debugging purposes initialise the block: */
+  jitterlisp_object *p;
+  for (p = (jitterlisp_object *) litter_allocator_pointer;
+       p < (jitterlisp_object *) litter_allocator_limit;
+       p ++)
+    * p = JITTERLISP_UNINITIALIZED_HEAP_VALUE;
+
   /* Add information about it to the stack. */
   struct jitterlisp_litter_block block;
   block.beginning = litter_heap_beginning;
@@ -415,7 +422,7 @@ jitterlisp_allocate (size_t size_in_bytes)
 #if   defined(JITTERLISP_LITTER)
   char *res = litter_allocator_pointer;
   litter_allocator_pointer += size_in_bytes;
-  if (__builtin_expect (litter_allocator_pointer > litter_allocator_limit,
+  if (__builtin_expect (litter_allocator_pointer >= litter_allocator_limit,
                         false))
     {
       size_t new_block_size = JITTERLISP_LITTER_BLOCK_BYTE_NO;
@@ -524,7 +531,7 @@ jitterlisp_gc (void)
    This function is meant to be used with jitter_hash_for_all_bindings . */
 static void
 jitterlisp_add_binding_to_list (const union jitter_word key,
-                                const union jitter_word value,
+                                union jitter_word * value_p,
                                 void *extra_datum)
 {
   jitterlisp_object * list_pointer = extra_datum;
@@ -532,7 +539,7 @@ jitterlisp_add_binding_to_list (const union jitter_word key,
   /* We don't need to do anything with the symbol name here: we only care about
      the value part of the binding.  Encode the symbol, which is stored
      unencoded in the symbol table. */
-  jitterlisp_object symbol = JITTERLISP_SYMBOL_ENCODE(value.pointer);
+  jitterlisp_object symbol = JITTERLISP_SYMBOL_ENCODE(value_p->pointer);
 
   /* Update the pointed list to contain another cons. */
   * list_pointer = jitterlisp_cons (symbol, * list_pointer);
