@@ -1,6 +1,6 @@
 /* pvm-val.c - Memory allocator for the PVM.  */
 
-/* Copyright (C) 2019, 2020, 2021, 2022, 2023 Jose E. Marchesi */
+/* Copyright (C) 2019, 2020, 2021, 2022, 2023, 2024 Jose E. Marchesi */
 
 /* This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,6 +17,9 @@
  */
 
 #include <config.h>
+#include <assert.h>
+
+#define GC_THREADS
 #include <gc/gc.h>
 
 #include "pvm.h"
@@ -78,7 +81,10 @@ pvm_alloc_initialize ()
      been already initialized.  The later may happen if some other
      library or program uses the boehm GC.  */
   if (!GC_is_init_called ())
-    GC_INIT ();
+    {
+      GC_INIT ();
+      GC_allow_register_threads ();
+    }
 }
 
 void
@@ -100,3 +106,24 @@ pvm_alloc_remove_gc_roots (void *pointer, size_t nelems)
   GC_remove_roots (pointer,
                    ((char*) pointer) + sizeof (void*) * nelems);
 }
+
+void
+pvm_alloc_register_thread ()
+{
+  struct GC_stack_base sb;
+  int ok_p __attribute__ ((unused));
+
+  ok_p = GC_get_stack_base (&sb) == GC_SUCCESS;
+  assert (ok_p);
+  /* The following call may return GC_SUCCESS or GC_DUPLICATE.  */
+  GC_register_my_thread (&sb);
+}
+
+void
+pvm_alloc_unregister_thread ()
+{
+  int ok_p __attribute__ ((unused));
+
+  ok_p = GC_unregister_my_thread () == GC_SUCCESS;
+  assert (ok_p);
+}
