@@ -1,6 +1,6 @@
 /* pk-hserver.h - A terminal hyperlinks server for poke.  */
 
-/* Copyright (C) 2019, 2021 Jose E. Marchesi */
+/* Copyright (C) 2019, 2021, 2022, 2023, 2024 Jose E. Marchesi */
 
 /* This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,6 +20,7 @@
 #define PK_HSERVER_H
 
 #include <config.h>
+#include "libpoke.h"
 
 /* Initialize the server.  */
 void pk_hserver_init (void);
@@ -29,13 +30,14 @@ void pk_hserver_start (void);
 void pk_hserver_shutdown (void);
 
 /* Get a new token.  */
-int pk_hserver_get_token (void);
+unsigned int pk_hserver_get_token (void);
 
 /* Return the port number where the server is listening.  This
    function shall be called after pk_hserver_init.  */
 int pk_hserver_port (void);
 
 /* Build hyperlinks.  */
-char *pk_hserver_make_hyperlink (char type, const char *cmd);
+char *pk_hserver_make_hyperlink (char type, const char *cmd,
+                                 pk_val function);
 
 #endif /* PK_HSERVER_H */
